==> stack_reporter-1.0.0.tar.gz: stack_reporter/src/Controller/StackReporterController.php <==
<?php

declare(strict_types=1);

namespace Drupal\stack_reporter\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\stack_reporter\Service\ModuleListService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Returns responses for Stack Reporter routes.
 */
class StackReporterController {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The module list service.
   *
   * @var \Drupal\stack_reporter\Service\ModuleListService
   */
  protected $moduleListService;

  /**
   * Constructs a new ApiController object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   * @param \Drupal\stack_reporter\Service\ModuleListService $moduleListService
   *   The module list service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, RequestStack $request_stack, ModuleListService $moduleListService) {
    $this->configFactory = $config_factory;
    $this->requestStack = $request_stack;
    $this->moduleListService = $moduleListService;
  }

  /**
   * Creates an instance of the controller.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('request_stack'),
      $container->get('stack_reporter.module_list_service')
    );
  }

  /**
   * Builds the response.
   */
  public function handle(): JsonResponse {
    $php_version = phpversion();
    $modules = $this->moduleListService->listModules();
    $packages = $this->moduleListService->getComposerPackages();

    // Try to get Node.js version.
    $node_version = '';
    try {
      // Use exec to run node -v command.
      $output = [];
      $return_var = 0;
      exec('which node && node -v 2>&1', $output, $return_var);
      if ($return_var === 0 && !empty($output)) {
        // Clean the version string (remove 'v' prefix if present)
        $node_version = trim(str_replace('v', '', end($output)));
      }
    }
    catch (\Exception $e) {
      // If exec is disabled or any other error occurs.
      $node_version = '';
    }

    // Replace this with your actual data.
    $data = [
      'drupal_version' => \Drupal::VERSION,

      // Server runtime environment (e.g., Node, PHP).
      'php_version' => $php_version,
      'node_version' => $node_version,
    ];

    return new JsonResponse($data);
  }

  /**
   * {@inheritdoc}
   */
  public function access() {
    $config = $this->configFactory->get('stack_reporter.settings');
    $internalKey = $config->get('apikey');

    $request = $this->requestStack->getCurrentRequest();
    $content = $request->getContent();
    $data = json_decode($content, TRUE);
    $externalKey = $data['apiKey'] ?? NULL;

    if ($externalKey && $internalKey === $externalKey) {
      return AccessResult::allowed();
    }
    else {
      return AccessResult::forbidden();
    }
  }

}

==> stack_reporter-1.0.1.tar.gz: stack_reporter/src/Controller/StackReporterController.php <==
<?php

declare(strict_types=1);

namespace Drupal\stack_reporter\Controller;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\stack_reporter\Service\ModuleListService;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\JsonResponse;
use Symfony\Component\HttpFoundation\RequestStack;

/**
 * Returns responses for Stack Reporter routes.
 */
class StackReporterController {

  /**
   * The configuration factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  protected $configFactory;

  /**
   * The request stack.
   *
   * @var \Symfony\Component\HttpFoundation\RequestStack
   */
  protected $requestStack;

  /**
   * The module list service.
   *
   * @var \Drupal\stack_reporter\Service\ModuleListService
   */
  protected $moduleListService;

  /**
   * Constructs a new ApiController object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The configuration factory.
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   *   The request stack.
   * @param \Drupal\stack_reporter\Service\ModuleListService $moduleListService
   *   The module list service.
   */
  public function __construct(ConfigFactoryInterface $config_factory, RequestStack $request_stack, ModuleListService $moduleListService) {
    $this->configFactory = $config_factory;
    $this->requestStack = $request_stack;
    $this->moduleListService = $moduleListService;
  }

  /**
   * Creates an instance of the controller.
   *
   * @param \Symfony\Component\DependencyInjection\ContainerInterface $container
   *   The service container.
   *
   * @return static
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('request_stack'),
      $container->get('stack_reporter.module_list_service')
    );
  }

  /**
   * Builds the response.
   */
  public function handle(): JsonResponse {
    $php_version = phpversion();
    $modules = $this->moduleListService->listModules();
    $packages = $this->moduleListService->getComposerPackages();

    // Try to get Node.js version.
    $node_version = '';
    try {
      // Use exec to run node -v command.
      $output = [];
      $return_var = 0;
      exec('which node && node -v 2>&1', $output, $return_var);
      if ($return_var === 0 && !empty($output)) {
        // Clean the version string (remove 'v' prefix if present)
        $node_version = trim(str_replace('v', '', end($output)));
      }
    }
    catch (\Exception $e) {
      // If exec is disabled or any other error occurs.
      $node_version = '';
    }

    // Replace this with your actual data.
    $data = [
      'drupal_version' => \Drupal::VERSION,

      // Server runtime environment (e.g., Node, PHP).
      'php_version' => $php_version,
      'node_version' => $node_version,
    ];

    return new JsonResponse($data);
  }

  /**
   * {@inheritdoc}
   */
  public function access() {
    $config = $this->configFactory->get('stack_reporter.settings');
    $internalKey = $config->get('apikey');

    $request = $this->requestStack->getCurrentRequest();
    $content = $request->getContent();
    $data = json_decode($content, TRUE);
    $externalKey = $data['apikey'] ?? NULL;

    if ($externalKey && $internalKey === $externalKey) {
      return AccessResult::allowed();
    }
    else {
      return AccessResult::forbidden();
    }
  }

}
